@@ -36,6 +36,8 @@ class Settings(object):
                  user_registration_url='https://www.cloudcontrol.com',
                  register_addon_url=None,
                  login_name='Email   : ',
+                 login_creds={'email': 'CCTRL_EMAIL',
+                              'pwd': 'CCTRL_PASSWORD'},
                  package_name='cctrl'):
 
         self.ssh_forwarder = ssh_forwarder_url or env.get('SSH_FORWARDER', 'sshforwarder.cloudcontrolled.com')
@@ -47,4 +49,5 @@ class Settings(object):
         self.user_registration_url = user_registration_url
         self.register_addon_url = register_addon_url
         self.login_name = login_name
+        self.login_creds = login_creds
         self.package_name = package_name
